rule win_wormhole_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.wormhole."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.wormhole"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { eb1b 3d04000100 752a a1???????? 68???????? 6a06 }
            // n = 6, score = 200
            //   eb1b                 | jmp                 0x1d
            //   3d04000100           | cmp                 eax, 0x10004
            //   752a                 | jne                 0x2c
            //   a1????????           |                     
            //   68????????           |                     
            //   6a06                 | push                6

        $sequence_1 = { 50 56 e8???????? 83c40c 8d4c2408 8d942414010000 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d4c2408             | lea                 ecx, [esp + 8]
            //   8d942414010000       | lea                 edx, [esp + 0x114]

        $sequence_2 = { ffd3 6a00 6a00 89442418 8d442428 }
            // n = 5, score = 200
            //   ffd3                 | call                ebx
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   89442418             | mov                 dword ptr [esp + 0x18], eax
            //   8d442428             | lea                 eax, [esp + 0x28]

        $sequence_3 = { e8???????? a1???????? 83c404 50 ff15???????? c705????????00000000 c705????????00000000 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   a1????????           |                     
            //   83c404               | add                 esp, 4
            //   50                   | push                eax
            //   ff15????????         |                     
            //   c705????????00000000     |     
            //   c705????????00000000     |     

        $sequence_4 = { 75f0 a1???????? 85c0 74d5 e8???????? }
            // n = 5, score = 200
            //   75f0                 | jne                 0xfffffff2
            //   a1????????           |                     
            //   85c0                 | test                eax, eax
            //   74d5                 | je                  0xffffffd7
            //   e8????????           |                     

        $sequence_5 = { c705????????01000000 68f4010000 ff15???????? 8b15???????? 52 e8???????? }
            // n = 6, score = 200
            //   c705????????01000000     |     
            //   68f4010000           | push                0x1f4
            //   ff15????????         |                     
            //   8b15????????         |                     
            //   52                   | push                edx
            //   e8????????           |                     

        $sequence_6 = { 85f6 7512 6a04 68???????? 6a28 57 e8???????? }
            // n = 7, score = 200
            //   85f6                 | test                esi, esi
            //   7512                 | jne                 0x14
            //   6a04                 | push                4
            //   68????????           |                     
            //   6a28                 | push                0x28
            //   57                   | push                edi
            //   e8????????           |                     

        $sequence_7 = { 6a78 6a28 57 50 e8???????? }
            // n = 5, score = 200
            //   6a78                 | push                0x78
            //   6a28                 | push                0x28
            //   57                   | push                edi
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_8 = { 8b442404 56 57 8b7c2410 6a78 6a28 }
            // n = 6, score = 200
            //   8b442404             | mov                 eax, dword ptr [esp + 4]
            //   56                   | push                esi
            //   57                   | push                edi
            //   8b7c2410             | mov                 edi, dword ptr [esp + 0x10]
            //   6a78                 | push                0x78
            //   6a28                 | push                0x28

        $sequence_9 = { 7564 8b442418 3dff000000 7f59 6a0f }
            // n = 5, score = 200
            //   7564                 | jne                 0x66
            //   8b442418             | mov                 eax, dword ptr [esp + 0x18]
            //   3dff000000           | cmp                 eax, 0xff
            //   7f59                 | jg                  0x5b
            //   6a0f                 | push                0xf

    condition:
        7 of them and filesize < 99576
}